What's new in version 1.3.8
===========================
Version available since March 29th 2024

New Features
------------
- Abstract class ODESystem in ode_tools to call when you define dynamic system.
- Abstract classes TimeFeature and FreqFeature to call when you define features to extract from the simulation.

Changes
-------
- Input variables in Spec (variables) can be written with a set instead of a dict if there is no need to initialize inputs.
- Normalization of constraints in f_penalty function (between 0 and 1).
- Class diagram updated with new defined abstract classes.
- API in documentation.

Bug fixed
---------
- 'from jax import config' instead of 'from jax.config import config' at the beginning of files.

Contributors
------------
Lucas Agobert
